==> petal_qc-0.0.4-py3-none-any.whl: petal_qc/metrology/do_Metrology.py <==
#!/usr/bin/env python3
"""Does metrology of all files listed at input file.

Examples:

python3 ~/cernbox/workspace/Petal-QC/do_Metrology.py ~/Desktop/petal-metrology-files.txt
python3 ~/cernbox/workspace/Petal-QC/do_Metrology.py --desy ~/Desktop/DESY-petal-metrology.txt

"""
import json
import sys
import traceback
from argparse import Action
from argparse import ArgumentParser
from pathlib import Path
import numpy as np

try:
    import petal_qc

except ImportError:
    cwd = Path(__file__).parent.parent.parent
    sys.path.append(cwd.as_posix())

from petal_qc.utils.utils import output_folder

from petal_qc.metrology.PetalMetrology import petal_metrology


class CommaSeparatedListAction(Action):
    """Create a list from the comma sepparated numbers at imput."""

    def __call__(self, parser, namespace, values, option_string=None):
        """The actual action."""
        value = np.array(list(map(float, values.split(','))), dtype='float64')
        if value.shape[0] < 3:
            raise Exception("{} needs a 3D vector".format(self.dest))

        setattr(namespace, self.dest, value)

def do_analysis(fnam, prefix, SN, options):
    """Perform analysis of a file.

    Args:
        fnam (): Input data file
        prefix (): Prefix telling if it is front or back
        SN (): Core serial number
        options (): Options.
        
    """
    
    is_front = prefix.lower().find("front") >= 0
    print(fnam, prefix)
    options.out = prefix + '.docx'
    options.title = prefix
    options.is_front = is_front
    if not hasattr(options, "SN"):
        options.SN = ""

    options.SN = SN
    outDB = petal_metrology(fnam, options)

    ofile = output_folder(options.folder, prefix + '.json')
    with open(ofile, 'w', encoding='UTF-8') as of:
        json.dump(outDB, of, indent=3)
    
    return outDB

def main(ifile, options):
    """Main entry."""
    with open(ifile, 'r', encoding='UTF-8') as inp:

        for line in inp:
            line = line.strip()
            if len(line) == 0:
                continue

            if line[0] == '#':
                continue

            SN = ""
            try:
                fnam, prefix = line.split()
            except Exception:
                fnam, prefix, SN, *_ = line.split()

            do_analysis(fnam, prefix, SN, options)


if __name__ == "__main__":
    parser = ArgumentParser()
    parser.add_argument('files', nargs='*', help="Input files")
    parser.add_argument("--prefix", dest='prefix', default=None)
    parser.add_argument("--SN", dest='SN', default=None)
    parser.add_argument("--save", dest='save', action="store_true", default=False)
    parser.add_argument("--desy", dest='desy', action="store_true", default=False)
    parser.add_argument("--out", dest="out", default="petal_flatness.docx",
                        type=str, help="The output fiel name")
    parser.add_argument("--bottom-lp", dest='bLP', action=CommaSeparatedListAction, default=None,
                        help="Bottom locking point fiducial coordinates")
    parser.add_argument("--upper-lp", dest='uLP', action=CommaSeparatedListAction, default=None,
                        help="upper locking point fiducials coordinates")

    parser.add_argument("--title", dest="title", default=None,
                        type=str, help="Document title")
    parser.add_argument("--nbins", dest="nbins", default=25,
                        type=int, help="Number of bins")
    parser.add_argument("--folder", default=None, help="Folder to store output files. Superseeds folder in --out")
    parser.add_argument("--locking_points", action="store_true", default=False)

    # This is to convert a CMM file
    parser.add_argument("--label", default="\\w+", help="The label to select")
    parser.add_argument("--type", default="Punto", help="The class to select")

    options = parser.parse_args()
    if len(options.files) == 0:
        print(sys.argv[0])
        print("I need an input file")
        sys.exit()

    try:
        main(options.files[0], options)

    except Exception:
        print(traceback.format_exc())

==> petal_qc-0.0.8-py3-none-any.whl: petal_qc/metrology/do_Metrology.py <==
#!/usr/bin/env python3
"""Does metrology of all files listed at input file.

Examples:

python3 ~/cernbox/workspace/Petal-QC/do_Metrology.py ~/Desktop/petal-metrology-files.txt
python3 ~/cernbox/workspace/Petal-QC/do_Metrology.py --desy ~/Desktop/DESY-petal-metrology.txt

"""
import json
import sys
import traceback
from argparse import Action
from argparse import ArgumentParser
from pathlib import Path
import numpy as np

try:
    import petal_qc

except ImportError:
    cwd = Path(__file__).parent.parent.parent
    sys.path.append(cwd.as_posix())

from petal_qc.utils.utils import output_folder

from petal_qc.metrology.PetalMetrology import petal_metrology


class CommaSeparatedListAction(Action):
    """Create a list from the comma sepparated numbers at imput."""

    def __call__(self, parser, namespace, values, option_string=None):
        """The actual action."""
        value = np.array(list(map(float, values.split(','))), dtype='float64')
        if value.shape[0] < 3:
            raise Exception("{} needs a 3D vector".format(self.dest))

        setattr(namespace, self.dest, value)

def do_analysis(fnam, prefix, SN, options):
    """Perform analysis of a file.

    Args:
        fnam: Input data file
        prefix: Prefix telling if it is front or back
        SN: Core serial number
        options: Options.

    """

    is_front = prefix.lower().find("front") >= 0
    print(fnam, prefix)
    options.out = prefix + '.docx'
    options.title = prefix
    options.is_front = is_front
    if not hasattr(options, "SN"):
        options.SN = ""

    options.SN = SN
    outDB = petal_metrology(fnam, options)

    ofile = output_folder(options.folder, prefix + '.json')
    with open(ofile, 'w', encoding='UTF-8') as of:
        json.dump(outDB, of, indent=3)

    return outDB

def analyze_files(ifile, options):
    """Main entry."""
    with open(ifile, 'r', encoding='UTF-8') as inp:

        for line in inp:
            line = line.strip()
            if len(line) == 0:
                continue

            if line[0] == '#':
                continue

            SN = ""
            try:
                fnam, prefix = line.split()
            except Exception:
                fnam, prefix, SN, *_ = line.split()

            do_analysis(fnam, prefix, SN, options)

def main():
    "Main entry."
    parser = ArgumentParser()
    parser.add_argument('files', nargs='*', help="Input files")
    parser.add_argument("--prefix", dest='prefix', default=None, help="prefix telling if it is front or back.")
    parser.add_argument("--SN", dest='SN', default=None, help="The petal core Serial Number")
    parser.add_argument("--save", dest='save', action="store_true", default=False)
    parser.add_argument("--desy", dest='desy', action="store_true", default=False, help="True if data is from DESY's SmartScope")
    parser.add_argument("--out", dest="out", default="petal_flatness.docx",
                        type=str, help="The output file name")
    parser.add_argument("--bottom-lp", dest='bLP', action=CommaSeparatedListAction, default=None,
                        help="Bottom locking point fiducial coordinates")
    parser.add_argument("--upper-lp", dest='uLP', action=CommaSeparatedListAction, default=None,
                        help="upper locking point fiducials coordinates")

    parser.add_argument("--title", dest="title", default=None,
                        type=str, help="Report Document title")
    parser.add_argument("--nbins", dest="nbins", default=25,
                        type=int, help="Number of bins in the histograms")
    parser.add_argument("--folder", default=None, help="Folder to store output files. Superseeds folder in --out")
    parser.add_argument("--locking_points", action="store_true", default=False)

    # This is to convert a CMM file
    parser.add_argument("--label", default="\\w+", help="The label to select")
    parser.add_argument("--type", default="Punto", help="The class to select")

    options = parser.parse_args()
    if len(options.files) == 0:
        print(sys.argv[0])
        print("I need an input file")
        sys.exit()

    try:
        analyze_files(options.files[0], options)

    except Exception:
        print(traceback.format_exc())

if __name__ == "__main__":
    main()
